pub enum OperationOutcome {
DefiniteFailure,
SafeToRetry,
Uncertain,
}Expand description
Retry/recovery safety of an NFS operation after an authoritative result is unavailable.
Variants
DefiniteFailure
The request is known not to have taken effect.
SafeToRetry
Repeating the operation is safe because it is read-only or idempotent.
Uncertain
The request may have taken effect; blind retry can duplicate a mutation.