pub enum RequestTransmission {
NotSent,
Sent,
}Expand description
Whether the request crossed the transport send boundary.
Variants
NotSent
The core proved that no request bytes were sent.
Sent
The request crossed the send boundary and may have reached the server.