pub struct OperationOutcomeError {
pub outcome: OperationOutcome,
pub operation_class: OperationClass,
pub transmission: RequestTransmission,
pub recovery: RecoveryAction,
pub completed_bytes: Option<u64>,
pub source: Box<NfsError>,
/* private fields */
}Expand description
Structured disposition for an operation whose normal result was not returned.
Fields
outcome: OperationOutcomeoperation_class: OperationClasstransmission: RequestTransmissionrecovery: RecoveryActioncompleted_bytes: Option<u64>source: Box<NfsError>Implementations
Sourceimpl OperationOutcomeError
impl OperationOutcomeError
pub fn new( outcome: OperationOutcome, operation_class: OperationClass, recovery: RecoveryAction, context: RequestContext, source: NfsError, ) -> Self
pub fn context(&self) -> &RequestContext
Sourcepub fn with_completed_bytes(self, completed_bytes: u64) -> Self
pub fn with_completed_bytes(self, completed_bytes: u64) -> Self
Records bytes completed by authoritative preceding chunks. The current uncertain chunk must never be included in this count.